==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_68.js <==
var searchData=
[
  ['h',['h',['../structtriangle.html#a82dbd6f31285b6c60e4c035417c6716b',1,'triangle::h()'],['../structcsa.html#acba79cb4f4eb19929c067cf52e145131',1,'csa::h()'],['../structplplot_1_1__N10.html#ae099434248d49c9374af650a07cf4b10',1,'plplot::_N10::h()'],['../structPLControlPt.html#a73674db8c26cba9caffc05e49c55e6cd',1,'PLControlPt::h()']]],
  ['hack',['hack',['../structPLStream.html#ac98930296aded0072e2beaeb4c8dcdbd',1,'PLStream']]],
  ['handler',['handler',['../structPLOptionTable.html#ab6dca4025110f8770f16f57016402247',1,'PLOptionTable']]],
  ['has_5fstring_5flength',['has_string_length',['../structPLStream.html#abb61b1a584d5cbce8a389a7df736cd9b',1,'PLStream']]],
  ['hasalpha',['hasAlpha',['../aqt_8c.html#ae34bdcef7e730aa1e350245620013128',1,'aqt.c']]],
  ['hascoeffs',['hascoeffs',['../structtriangle.html#a76fa4a762d76a9c09436bbaca8153dbf',1,'triangle']]],
  ['hash',['hash',['../structhashtable.html#ada2423b92f4c35ba085f0657d13d9d89',1,'hashtable']]],
  ['hasshear',['hasShear',['../aqt_8c.html#a05494dfe54e9cdc2aef92f11d20d8f57',1,'aqt.c']]],
  ['head',['head',['../tclMatrix_8c.html#ae1859da70930176a2e2e760d5fd586dd',1,'tclMatrix.c']]],
  ['header',['header',['../deltaT-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;deltaT-gen.c'],['../tai-utc-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;tai-utc-gen.c']]],
  ['height',['height',['../classwxPLDevBase.html#aea5e1f836090fa9329ecafc1e61e953e',1,'wxPLDevBase::height()'],['../structplplot_1_1__N4.html#af0fcd17063b1211df598d89ab23d8361',1,'plplot::_N4::height()'],['../structPlFrame.html#a753f618be981a067497386eaba0689de',1,'PlFrame::height()'],['../structTkDev.html#a93af910ff8947e3db175cd7a00f36f9d',1,'TkDev::height()'],['../structPlPlotter.html#a91881b075adcf699c51d4457497e1136',1,'PlPlotter::height()'],['../structTkwDev.html#abebe7feeebbabbd8fbf9f13f9e3ec748',1,'TkwDev::height()'],['../structGcwPLdev.html#ad5ea3d3f2fca3485462c59bb25a702b9',1,'GcwPLdev::height()'],['../structPLDisplay.html#abfc69cbabc752b85010ad60e8cd2c1d1',1,'PLDisplay::height()'],['../structXwDev.html#a945f683c2d2fcb353d8a2484cc79338c',1,'XwDev::height()']]],
  ['hershey',['Hershey',['../structHershey__to__Unicode__table.html#a7747e2b55ce7b3f926422674bf7a98e2',1,'Hershey_to_Unicode_table']]],
  ['hershey_5fto_5funicode_5flookup_5ftable',['hershey_to_unicode_lookup_table',['../plplotP_8h.html#a018bc4e28f0a17e8e928a7815f866b43',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h'],['../plhershey-unicode_8h.html#a1aa0c83f54d4d4823a76ab89ac80ce16',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h']]],
  ['high_5fcap_5fcolor',['high_cap_color',['../plplot__octave_8h.html#abb0ae89470f54dd69ea180fa9a5a4c71',1,'plplot_octave.h']]],
  ['hinstlib',['hinstLib',['../struct____dlhandle.html#ad612da9abe95210282423ac7bd98bfa4',1,'__dlhandle']]],
  ['hlp_5fmsg',['hlp_msg',['../structDrvOpt.html#a57e8cd1b98d06fefc2264e957e1c524e',1,'DrvOpt']]],
  ['hrshsym',['hrshsym',['../gcw_8c.html#aa20a33fff795f0a9b965f3a914eca6b2',1,'gcw.c']]],
  ['ht_5fdata',['ht_data',['../structnnhpi.html#a126ee669cab3462cbc52b7a329beaba1',1,'nnhpi']]],
  ['ht_5fweights',['ht_weights',['../structnnhpi.html#ac51966e4ed100e61f47fbf3887a19a7b',1,'nnhpi']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_68.js <==
var searchData=
[
  ['h',['h',['../structtriangle.html#a82dbd6f31285b6c60e4c035417c6716b',1,'triangle::h()'],['../structcsa.html#acba79cb4f4eb19929c067cf52e145131',1,'csa::h()'],['../structplplot_1_1__N10.html#ae099434248d49c9374af650a07cf4b10',1,'plplot::_N10::h()'],['../structPLControlPt.html#a73674db8c26cba9caffc05e49c55e6cd',1,'PLControlPt::h()']]],
  ['hack',['hack',['../structPLStream.html#ac98930296aded0072e2beaeb4c8dcdbd',1,'PLStream']]],
  ['handler',['handler',['../structPLOptionTable.html#ad5c9d7750a254ebc521db666d0ecc6fd',1,'PLOptionTable']]],
  ['has_5fstring_5flength',['has_string_length',['../structPLStream.html#abb61b1a584d5cbce8a389a7df736cd9b',1,'PLStream']]],
  ['hasalpha',['hasAlpha',['../aqt_8c.html#ae34bdcef7e730aa1e350245620013128',1,'aqt.c']]],
  ['hascoeffs',['hascoeffs',['../structtriangle.html#a76fa4a762d76a9c09436bbaca8153dbf',1,'triangle']]],
  ['hash',['hash',['../structhashtable.html#ada2423b92f4c35ba085f0657d13d9d89',1,'hashtable']]],
  ['hasshear',['hasShear',['../aqt_8c.html#a05494dfe54e9cdc2aef92f11d20d8f57',1,'aqt.c']]],
  ['head',['head',['../tclMatrix_8c.html#ae1859da70930176a2e2e760d5fd586dd',1,'tclMatrix.c']]],
  ['header',['header',['../deltaT-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;deltaT-gen.c'],['../tai-utc-gen_8c.html#a2d5bf705d4e4df438762a5c261d6e530',1,'header():&#160;tai-utc-gen.c']]],
  ['height',['height',['../structTextSizeInfo.html#ae16b2b6b80bf45ef08e0baf075186960',1,'TextSizeInfo::height()'],['../structplplot_1_1__N4.html#af0fcd17063b1211df598d89ab23d8361',1,'plplot::_N4::height()'],['../structPlFrame.html#a753f618be981a067497386eaba0689de',1,'PlFrame::height()'],['../structTkDev.html#a93af910ff8947e3db175cd7a00f36f9d',1,'TkDev::height()'],['../structPlPlotter.html#a91881b075adcf699c51d4457497e1136',1,'PlPlotter::height()'],['../structTkwDev.html#abebe7feeebbabbd8fbf9f13f9e3ec748',1,'TkwDev::height()'],['../structPLDisplay.html#abfc69cbabc752b85010ad60e8cd2c1d1',1,'PLDisplay::height()'],['../structXwDev.html#a945f683c2d2fcb353d8a2484cc79338c',1,'XwDev::height()']]],
  ['hershey',['Hershey',['../structHershey__to__Unicode__table.html#a7747e2b55ce7b3f926422674bf7a98e2',1,'Hershey_to_Unicode_table']]],
  ['hershey_5fto_5funicode_5flookup_5ftable',['hershey_to_unicode_lookup_table',['../plplotP_8h.html#a018bc4e28f0a17e8e928a7815f866b43',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h'],['../plhershey-unicode_8h.html#a1aa0c83f54d4d4823a76ab89ac80ce16',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h']]],
  ['hinstlib',['hinstLib',['../struct____dlhandle.html#ad612da9abe95210282423ac7bd98bfa4',1,'__dlhandle']]],
  ['hlp_5fmsg',['hlp_msg',['../structDrvOpt.html#a57e8cd1b98d06fefc2264e957e1c524e',1,'DrvOpt']]],
  ['ht_5fdata',['ht_data',['../structnnhpi.html#a126ee669cab3462cbc52b7a329beaba1',1,'nnhpi']]],
  ['ht_5fweights',['ht_weights',['../structnnhpi.html#ac51966e4ed100e61f47fbf3887a19a7b',1,'nnhpi']]]
];
